<?php
/*
Plugin Name: Widget Pagination
Plugin URI: http://wgpag.jana-sieber.de/
Description: This plugin lets you add a pagination for the widgets links, categories, archives, recent posts, recent comments, and meta.
Version: 0.2
Author: Jana Sieber [janasieber] and Lars Uebernickel
Author URI: http://wordpress.org/support/profile/janasieber
License: GPL2
*/

/*  Copyright 2011  Jana Sieber <jana@jana-sieber.de>
                    Lars Uebernickel <lars@uebernic.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
?>
<?php
define("WGPAG_VERSION", "0.1");

if (!class_exists('WidgetPagination')) {

    class WidgetPagination {

        private $widgets = array(
            'links'           => 'Links',
            'categories'      => 'Categories',
            'archives'        => 'Archives',
            'recent_entries'  => 'Recent Posts',
            'recent_comments' => 'Recent Comments',
            'meta'            => 'Meta');

        function __construct() {

            // In dashboard
            if ( is_admin() ) {
                add_action('admin_init', array($this, 'wgpag_admin_init')); //register_setting
                add_action('admin_menu', array($this, 'wgpag_admin_menu'));
                register_activation_hook(__FILE__, array(&$this, 'initialize_defaults'));

                // Widget Pagination update options
                if ( isset($_POST['wgpag']) && $_POST['wgpag']=='true' ) {

                    // print '<pre>' . print_r ($_POST, true) . '</pre>';

                    foreach ($_POST as $name => $value) {
                        if (preg_match('/^wgpag-items_per_page_(.*)/', $name, $matches) &&
                            isset($this->widgets[$matches[1]]))
                            update_option($name, $value);
                    }

                    if (!empty($_POST['wgpag-pag_option_ptsh']))
                        update_option('wgpag-pag_option_ptsh', $_POST['wgpag-pag_option_ptsh']);
                    if (!empty($_POST['wgpag-pag_option_prev']))
                        update_option('wgpag-pag_option_prev', $_POST['wgpag-pag_option_prev']);
                    if (!empty($_POST['wgpag-pag_option_next']))
                        update_option('wgpag-pag_option_next', $_POST['wgpag-pag_option_next']);
                }
            }

            // Not in dashboard
            if ( !is_admin() ) {
                add_action('init', array($this, 'wgpag_page_init') );
            }
        }

        /**
         * Initialize defaults
         * @author Jana Sieber
         */
        function initialize_defaults() {
            foreach ($this->widgets as $w => $name)
                add_option('wgpag-items_per_page_' . $w,'','','no');

            add_option('wgpag-pag_option_ptsh','7','','no');
            add_option('wgpag-pag_option_prev','<','','no');
            add_option('wgpag-pag_option_next','>','','no');
        }

        /**
         * Initialize WgPag
         * @author Jana Sieber
         */
        function wgpag_page_init() {
            wp_register_script('wgpag', plugins_url('/js/wgpag.js',__FILE__),
                               array('jquery'), WGPAG_VERSION );
            wp_register_style('wgpag', plugins_url('/css/wgpag.css',__FILE__),
                              '', WGPAG_VERSION );

            wp_enqueue_style('wgpag');
            wp_enqueue_script('wgpag');
            wp_enqueue_script('jquery');

            // send to js
            $widgets = array();
            foreach ($this->widgets as $w => $name) {
                $widgets[] = array(
                    'selector' => '.widget_' . $w,
                    'count' => (int)get_option('wgpag-items_per_page_' . $w)
                );
            }

            $options = array(
                'widgets'       => $widgets,
                'pages_to_show' => get_option('wgpag-pag_option_ptsh'),
                'prev_label'    => get_option('wgpag-pag_option_prev'),
                'next_label'    => get_option('wgpag-pag_option_next'));


            wp_localize_script('wgpag', 'wgpag_options',
                array('l10n_print_after' => 'wgpag_options = ' . json_encode($options) . ';'));
        }

        /**
         * Initialize WgPag admin (register settings)
         * @author Jana Sieber
         */
        function wgpag_admin_init() {
            wp_register_style('wgpag-style',
                              plugins_url('/css/admin.css',__FILE__),
                              '', WGPAG_VERSION );
            wp_register_script('wgpag-script',
                               plugins_url('/js/admin.js', __FILE__),
                              '', WGPAG_VERSION );
            //register_setting( 'widget_pagination', 'new_option_name' );
        }

        /**
         * Initialize WgPag admin panel
         * @author Jana Sieber
         */
        function wgpag_admin_menu() {
            $page = add_submenu_page('themes.php',
                                     'Widget Pagination',
                                     'Widget Pagination',
                                     'manage_options',
                                     __FILE__,
                                     array($this, 'wgpag_options_page'));
            add_action('admin_print_styles-'.$page,  array($this, 'wgpag_admin_styles'));
            add_action('admin_print_scripts-'.$page, array($this, 'wgpag_admin_scripts'));
        }

        /**
         * Load WgPag admin styles
         * @author Jana Sieber
         */
        function wgpag_admin_styles() {
            wp_enqueue_style('wgpag-style');
        }

        /**
         * Load WgPag admin scripts
         * @author Jana Sieber
         */
        function wgpag_admin_scripts() {
            wp_enqueue_script('wgpag-script');
        }

        /**
         * Provide markup for WgPag settings page
         * @author Jana Sieber
         */
        function wgpag_options_page() {
        ?>
            <div class="wrap" id="wgpag-options">
                <div class="icon32" id="icon-options-general"></div>

                <h2>Widget Pagination <?php _e("Settings") ?></h2>

                <p>Pagination for lists of blogroll links, categories, archives,
                    recent posts, recent comments and meta, that have been added
                    via <a href="widgets.php">widgets</a>.</p>

                <form method="post" action="#">

                    <?php
                    if ( isset($_POST['wgpag']) && $_POST['wgpag']=='true' ) {

                        //TODO: check, if this saving successfull

                        echo '<p class="success">Your settings have been saved!</p>';
                    }

                    // The setting fields will know which settings your options page will handle.
                    settings_fields('widget_pagination');
                    // replace the form-field markup in the form itself
                    //do_settings( 'baw-settings-group' );
                    ?>

                    <h3>Items per page</h3>

                    <p>If you want a pagination, enter the designated items per
                        page for each widget. Otherwise, leave it emtpy.</p>

                    <table class="form-table">
                        <?php
                        foreach ($this->widgets as $w => $name) {
                            $value = get_option('wgpag-items_per_page_' . $w);
                            $name = __($name);
                            echo <<<END
                              <tr>
                                <th>
                                  <label for="wgpag-items_per_page_$w">$name:</label>
                                </th>
                                <td>
                                  <input type="text" maxlength="2" size="2"
                                         name="wgpag-items_per_page_$w"
                                         id="wgpag-items_per_page_$w"
                                         class="wgpag-items_per_page"
                                         value="$value" />
                                </td>
                              </tr>
END;
                        }
                        ?>
                    </table>

                    <h3>Pagination options</h3>

                    <p>Here you can change the defaults for how the pagination is returned.</p>

                    <table class="form-table">
                        <tr>
                            <th>
                              <label for="wgpag-pag_option_ptsh">Pages to show:</label>
                            </th>
                            <td>
                              <input type="text" maxlength="2" size="2"
                                     name="wgpag-pag_option_ptsh"
                                     id="wgpag-pag_option_ptsh"
                                     class="wgpag-items_per_page"
                                     value="<? echo get_option('wgpag-pag_option_ptsh') ?>" />
                            </td>
                        </tr>
                        <tr>
                            <th>
                              <label for="wgpag-pag_option_prev">Previous label:</label>
                            </th>
                            <td>
                              <input type="text"
                                     name="wgpag-pag_option_prev"
                                     id="wgpag-pag_option_prev"
                                     class="wgpag-items_per_page"
                                     value="<? echo get_option('wgpag-pag_option_prev') ?>" />
                            </td>
                        </tr>
                        <tr>
                            <th>
                              <label for="wgpag-pag_option_next">Next label:</label>
                            </th>
                            <td>
                              <input type="text"
                                     name="wgpag-pag_option_next"
                                     id="wgpag-pag_option_next"
                                     class="wgpag-items_per_page"
                                     value="<? echo get_option('wgpag-pag_option_next') ?>" />
                            </td>
                        </tr>
                    </table>

                         <p class="submit">
                            <input type="hidden"
                                   value="<?php echo wp_create_nonce('wgpag-nonce'); ?>"
                                   name="wgpag-nonce" />
                            <input type="hidden" value="true" name="wgpag" />
                            <input type="submit" value="<?php _e('Save Changes') ?>"
                                   class="button-primary" id="submit" name="submit" />
                        </p>
                </form>

            </div>
        <?php
        }
    }
}

// Init Widget Pagination
$wgpag = new WidgetPagination();
?>